"""
Program ilustrující zápis do souboru jak v textovém, tak binárním režimu.
Pro zjednodušení je možné použít serializaci (pickling), která je sice jednodušší
na použití, než binární zápis, ale v souboru jsou obsaženy metainformace, tak má
pak větší velikost. Nicméně pro složené typy, je pickling jasná volba.
"""

import io
import pickle # modulu pro pickling

def zapis_cisla_binarne(pocet, cesta):
    """
    Funkce zapisující binárně celá čísla.
    Pro číslo použije čtyři Byte
    """
    with open(cesta, 'wb') as f:
        for cislo in range(pocet):
            f.write(cislo.to_bytes(4,byteorder='little'))

def zapis_cisla_binarne_pickling(pocet, cesta):
    """
    Funkce zapisující čísla. Používá serializaci objektů.
    """
    with open(cesta, 'wb') as f:
        for cislo in range(pocet):
            pickle.dump(cislo, f)


def zapis_cislo_textove(pocet,cesta):
    """
    Funkce zapisující celá čísla jako řetězce.
    """
    with open(cesta, 'w') as f:
        for cislo in range(pocet):
            f.write('{}'.format(cislo))



zapis_cisla_binarne(100000, "binarni.dat")
zapis_cisla_binarne_pickling(100000, "binarni2.dat")
zapis_cislo_textove(100000, "textove.txt")
